public class Edge
{
  /*
   * This class models an edge from vertex X to vertex Y -- pretty
   * straightforward. 
   *
   * It is a little wasteful to keep the starting vertex, since the 
   * adjacency list will do this for us -- but it makes the code
   * neater in other places (makes the Edge independent of the Adj. List
   */

   private int vertex_from; // Start vertex
   private int vertex_to;   // Destination vertex
   private int cost;        // Weight of edge from start to destination


   /*
    * This is the constructor for a _weighted_ edge
    */
   public Edge(int vertex_from, int vertex_to, int cost)
   {
     this.vertex_from = vertex_from;
     this.vertex_to = vertex_to;
     this.cost = cost;
   }

   /*
    * This is the constructor for an _un_weighted edge
    */
   public Edge(int vertex_from, int vertex_to)
   {
     this.vertex_from = vertex_from;
     this.vertex_to = vertex_to;
     this.cost = 0;
   }


   /*
    * Simple accessor to get the start vertex
    */
   int getStartVertex()
   {
     return vertex_from;
   }


   /*
    * Simple accessor to get the destination vertex
    */
   public int getDestinationVertex()
   {
     return vertex_to;
   }


   /*
    * Simple accessor to get the cost (a.k.a, weight) of the Edge
    */
   public int getCost()
   {
     return cost;
   }

   /*
    * Simple .equals() method, it does what you likely expect
    * It considers two edges equal if they go to the same
    * vertex, regardless of their weight
    */
   public boolean equals(Object other_edge)
   {
     return ( ((((Edge)other_edge).vertex_from == 
              ((Edge)this).vertex_from)) && 
              ((Edge)other_edge).vertex_to == vertex_to );

   }

		
   /*
    * Represents this Edge as a String and returns that String
    * Feel free to make this prettier, if you'd like.
    */
   public String toString()
   {
     return "{" + vertex_from + "," + vertex_to + "," + cost + "}";
   }
}
